import sh from 'mvdan-sh';
import { languages } from './languages';
var syntax = sh.syntax;
export default {
    name: 'prettier-plugin-sh',
    languages: languages,
    parsers: {
        sh: {
            parse: function (text, _parsers, _a) {
                var filepath = _a.filepath, 
                /* istanbul ignore next */ _b = _a.keepComments, 
                /* istanbul ignore next */ keepComments = _b === void 0 ? true : _b, stopAt = _a.stopAt, variant = _a.variant;
                var parserOptions = [syntax.KeepComments(keepComments)];
                /* istanbul ignore if */
                if (stopAt != null) {
                    parserOptions.push(syntax.StopAt(stopAt));
                }
                /* istanbul ignore if */
                if (variant != null) {
                    parserOptions.push(syntax.Variant(variant));
                }
                try {
                    return syntax.NewParser.apply(syntax, parserOptions).Parse(text, filepath);
                }
                catch (e) {
                    var err = e;
                    throw Object.assign(new SyntaxError(err.Text), {
                        loc: {
                            start: {
                                column: err.Pos.Col(),
                                line: err.Pos.Line(),
                            },
                        },
                    });
                }
            },
            astFormat: 'sh',
            locStart: /* istanbul ignore next */ function (node) { return node.Pos().Offset(); },
            locEnd: /* istanbul ignore next */ function (node) { return node.End().Offset(); },
        },
    },
    printers: {
        sh: {
            print: function (path, _a) {
                var useTabs = _a.useTabs, tabWidth = _a.tabWidth, 
                /* istanbul ignore next */ _b = _a.indent, 
                /* istanbul ignore next */ indent = _b === void 0 ? useTabs ? 0 : tabWidth : _b, 
                /* istanbul ignore next */ _c = _a.binaryNextLine, 
                /* istanbul ignore next */ binaryNextLine = _c === void 0 ? true : _c, switchCaseIndent = _a.switchCaseIndent, spaceRedirects = _a.spaceRedirects, keepPadding = _a.keepPadding, minify = _a.minify, functionNextLine = _a.functionNextLine;
                return syntax
                    .NewPrinter(syntax.Indent(indent), syntax.BinaryNextLine(binaryNextLine), syntax.SwitchCaseIndent(switchCaseIndent), syntax.SpaceRedirects(spaceRedirects), syntax.KeepPadding(keepPadding), syntax.Minify(minify), syntax.FunctionNextLine(functionNextLine))
                    .Print(path.getValue());
            },
        },
    },
};
//# sourceMappingURL=index.js.map